%global _hardened_build 1
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

Summary: High-performance authoritative DNS server
Name: knot
Version: 2.6.4
Release: 1%{?dist}
License: GPLv3
Group: System Environment/Daemons
URL: http://www.knot-dns.cz
Source0: http://public.nic.cz/files/knot-dns/%{name}-%{version}.tar.xz
Source1: http://public.nic.cz/files/knot-dns/%{name}-%{version}.tar.xz.asc
Source2: %{name}.service
Source3: %{name}.conf
Source4: %{name}.tmpfiles

# PGP keys used to sign upstream releases
# Export with --armor using command from https://fedoraproject.org/wiki/PackagingDrafts:GPGSignatures
# Don't forget to update %prep section when adding/removing keys
Source1000: gpgkey-742FA4E95829B6C5EAC6B85710BB7AF6FEBBD6AB.gpg.asc

# Required dependencies
BuildRequires: gnupg2
BuildRequires: pkgconfig(liburcu) pkgconfig(gnutls) >= 3.3 pkgconfig(nettle) lmdb-devel pkgconfig(libedit)
# Optional dependencies
BuildRequires: pkgconfig(libcap-ng) pkgconfig(libidn2) pkgconfig(libsystemd)
BuildRequires: systemd
%{!?rhel:
# RHEL ships protobuf only for subset of arches so we disable it in RHEL completely to avoid architecture-dependent build
BuildRequires: pkgconfig(libfstrm) pkgconfig(libprotobuf-c)
}

Requires: python-lmdb

Requires(post): python-lmdb
Requires(post): systemd %{_sbindir}/runuser
Requires(preun): systemd
Requires(postun): systemd

Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description
Knot DNS is a high-performance authoritative DNS server implementation.

%package libs
Summary: Libraries used by the Knot DNS server and client applications

%description libs
The package contains shared libraries used by the Knot DNS server and
utilities.

%package devel
Summary: Development header files for the Knot DNS libraries
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
The package contains development header files for the Knot DNS libraries
included in knot-libs package.

%package utils
Summary: DNS client utilities shipped with the Knot DNS server
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description utils
The package contains DNS client utilities shipped with the Knot DNS server.

%package doc
Summary: Documentation for the Knot DNS server
License: GPLv3 and BSD and MIT
BuildArch: noarch
%if 0%{?rhel}
BuildRequires: python-sphinx
%else
BuildRequires: python3-sphinx
%endif
Provides: bundled(jquery) = 3.1.0

%description doc
The package contains documentation for the Knot DNS server.
On-line version is available on https://www.knot-dns.cz/documentation/

%prep
export GNUPGHOME=./gpg-keyring
mkdir ${GNUPGHOME}
gpg2 --import %{SOURCE1000}
gpg2 --verify %{SOURCE1} %{SOURCE0}

%setup -q

# make sure embedded LMDB library is not used
rm -vr src/contrib/lmdb

%build
# disable debug code (causes unused warnings)
CFLAGS="%{optflags} -DNDEBUG -Wno-unused"

%ifarch armv7hl i686
# 32-bit architectures sometimes do not have sufficient amount of
# contiguous address space to handle default values
%define configure_db_sizes --with-conf-mapsize=64 --with-timer-mapsize=16
%endif

%configure %{configure_db_sizes}
make %{?_smp_mflags}
make html

%install
make install DESTDIR=%{buildroot}

# install documentation
mkdir -p %{buildroot}%{_pkgdocdir}
cp -av doc/_build/html %{buildroot}%{_pkgdocdir}
[ -r %{buildroot}%{_pkgdocdir}/html/index.html ] || exit 1
rm -f %{buildroot}%{_pkgdocdir}/html/.buildinfo

# install customized configuration file
rm %{buildroot}%{_sysconfdir}/%{name}/*
install -p -m 0644 -D %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# install service file and create rundir
install -p -m 0644 -D %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -p -m 0644 -D %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}%{_localstatedir}/run/%{name}

# create storage dir and key dir
mkdir -p %{buildroot}%{_sharedstatedir}
install -d -m 0775 %{buildroot}%{_sharedstatedir}/%{name}
install -d -m 0770 %{buildroot}%{_sharedstatedir}/%{name}/keys

# install config samples into docdir
install -d -m 0755 %{buildroot}%{_pkgdocdir}/samples
for sample_file in knot.sample.conf example.com.zone; do
    install -p -m 0644 samples/${sample_file} %{buildroot}%{_pkgdocdir}/samples
done

# remove static libraries and libarchive files
rm %{buildroot}%{_libdir}/*.a
rm %{buildroot}%{_libdir}/*.la

%check
make check

%pre
getent group knot >/dev/null || groupadd -r knot
getent passwd knot >/dev/null || useradd -r -g knot -d %{_sysconfdir}/knot -s /sbin/nologin -c "Knot DNS server" knot
exit 0

%post
%systemd_post knot.service
if [ $1 -gt 1 ] ; then  # upgrade
    if rpm -q --qf=%%{version} knot | grep -q "^1\." ; then  # detect versions 1.y.z
        echo 'Automatic upgrade from Knot DNS versions 1.y.z is not supported anymore'
        echo 'Contact https://www.knot-dns.cz/support/'
        exit 1
    fi

    # 2.[0-4].z -> 2.5+.z migration
    if rpm -q --qf=%%{version} knot | grep -q '^2.[0-4]\.' ; then
        # rename modules
        echo 'Migrating module names in configuration file /etc/knot/knot.conf'
        sed -i.rpmsave -e 's/\bmod-online-sign\b/mod-onlinesign/' -e 's/\bmod-synth-record\b/mod-synthrecord/' /etc/knot/knot.conf
        echo 'Migrating KASP database %{_sharedstatedir}/%{name}/keys from JSON files to LMDB database'
        # migrate keys into LMDB
        %{_sbindir}/runuser -u knot -- %{_sbindir}/pykeymgr -i %{_sharedstatedir}/%{name}/keys
    fi
fi


%preun
%systemd_preun knot.service

%postun
%systemd_postun_with_restart knot.service

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%{_pkgdocdir}/samples
%dir %attr(750,root,knot) %{_sysconfdir}/%{name}
%config(noreplace) %attr(640,root,knot) %{_sysconfdir}/%{name}/%{name}.conf
%dir %attr(775,root,knot) %{_sharedstatedir}/%{name}
%dir %attr(770,root,knot) %{_sharedstatedir}/%{name}/keys
%dir %attr(-,knot,knot) %{_localstatedir}/run/%{name}
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_bindir}/kjournalprint
%{_bindir}/kzonecheck
%{_sbindir}/keymgr
%{_sbindir}/knotc
%{_sbindir}/knotd
%{_sbindir}/pykeymgr
%{_mandir}/man1/kjournalprint.*
%{_mandir}/man1/kzonecheck.*
%{_mandir}/man5/knot.conf.*
%{_mandir}/man8/keymgr.*
%{_mandir}/man8/knotc.*
%{_mandir}/man8/knotd.*
%{_mandir}/man8/pykeymgr.*

%files utils
%{_bindir}/kdig
%{_bindir}/khost
%{_bindir}/knsec3hash
%{_bindir}/knsupdate
%{_mandir}/man1/kdig.*
%{_mandir}/man1/khost.*
%{_mandir}/man1/knsec3hash.*
%{_mandir}/man1/knsupdate.*

%files libs
%doc COPYING AUTHORS NEWS THANKS
%{_libdir}/libdnssec.so.*
%{_libdir}/libknot.so.*
%{_libdir}/libzscanner.so.*

%files devel
%{_includedir}/dnssec
%{_includedir}/knot
%{_includedir}/libknot
%{_includedir}/zscanner
%{_libdir}/libdnssec.so
%{_libdir}/libknot.so
%{_libdir}/libzscanner.so
%{_libdir}/pkgconfig/knotd.pc
%{_libdir}/pkgconfig/libdnssec.pc
%{_libdir}/pkgconfig/libknot.pc
%{_libdir}/pkgconfig/libzscanner.pc

%files doc
%dir %{_pkgdocdir}
%{_pkgdocdir}/html

%changelog
* Mon Jan 22 2018 Tomas Krizek <tomas.krizek@nic.cz> - 2.6.4-1
- Added PGP signature verification
- Added integration test

- New upstream release 2.6.4

Knot DNS 2.6.4 (2018-01-02)
===========================

Features:
---------
 - Module synthrecord allows multiple 'network' specification
 - New CSK handling support in keymgr

Improvements:
-------------
 - Allowed configuration for infinite zsk lifetime
 - Increased performance and security of the module synthrecord
 - Signing changeset is stored into journal even if 'zonefile-load' is whole

Bugfixes:
---------
 - Unintentional zone re-sign during reload if empty NSEC3 salt
 - Inconsistent zone names in journald structured logs
 - Malformed outgoing transfer for big zone with TSIG
 - Some minor DNSSEC-related issues

Knot DNS 2.6.3 (2017-11-24)
===========================

Bugfixes:
---------
 - Wrong detection of signing scheme rollover

Knot DNS 2.6.2 (2017-11-23)
===========================

Features:
---------
 - CSK algorithm rollover and (KSK, ZSK) <-> CSK rollover support

Improvements:
-------------
 - Allowed explicit configuration for infinite ksk lifetime
 - Proper error messages instead of unclear error codes in server log
 - Better support for old compilers

Bugfixes:
---------
 - Unexpected reply for DS query with an owner below a delegation point
 - Old dependencies in the pkg-config file


* Mon Nov 06 2017 Petr Špaček <petr.spacek@nic.cz> - 2.6.1-1
- New upstream release 2.6.1

Knot DNS 2.6.1 (2017-11-02)
===========================

Features:
---------
 - NSEC3 Opt-Out support in the DNSSEC signing
 - New CDS/CDNSKEY publish configuration option

Improvements:
-------------
 - Simplified DNSSEC log message with DNSKEY details
 - +tls-hostname in kdig implies +tls-ca if neither +tls-ca nor +tls-pin is given
 - New documentation sections for DNSSEC key rollovers and shared keys
 - Keymgr no longer prints useless algorithm number for generated key
 - Kdig prints unknown RCODE in a numeric format
 - Better support for LLVM libFuzzer

Bugfixes:
---------
 - Faulty DNAME semantic check if present in the zone apex and NSEC3 is used
 - Immediate zone flush not scheduled during the zone load event
 - Server crashes upon dynamic zone addition if a query module is loaded
 - Kdig fails to connect over TLS due to SNI is set to server IP address
 - Possible out-of-bounds memory access at the end of the input
 - TCP Fast Open enabled by default in kdig breaks TLS connection

Knot DNS 2.6.0 (2017-09-29)
===========================

Features:
---------
 - On-slave (inline) signing support
 - Automatic DNSSEC key algorithm rollover
 - Ed25519 algorithm support in DNSSEC (requires GnuTLS 3.6.0)
 - New 'journal-content' and 'zonefile-load' configuration options
 - keymgr tries to run as user/group set in the configuration
 - Public-only DNSSEC key import into KASP DB via keymgr
 - NSEC3 resalt and parent DS query events are persistent in timer DB
 - New processing state for a response suppression within a query module
 - Enabled server side TCP Fast Open if supported
 - TCP Fast Open support in kdig

Improvements:
-------------
 - Better record owner compression if related to the previous rdata dname
 - NSEC(3) chain is no longer recomputed whole on every update
 - Remove inconsistent and unnecessary quoting in log files
 - Avoiding of overlapping key rollovers at a time
 - More DNSSSEC-related semantic checks
 - Extended timestamp format in keymgr

Bugfixes:
---------
 - Incorrect journal free space computation causing inefficient space handling
 - Interface-automatic broken on Linux in the presence of asymmetric routing

Knot DNS 2.5.5 (2017-09-29)
===========================

Improvements:
-------------
 - Constant time memory comparison in the TSIG processing
 - Proper use of the ctype functions
 - Generated RRSIG records have inception time 90 minutes in the past

Bugfixes:
---------
 - Incorrect online signature for NSEC in the case of a CNAME record
 - Incorrect timestamps in dnstap records
 - EDNS Subnet Client validation rejects valid payloads
 - Module configuration semantic checks are not executed
 - Kzonecheck segfaults with unusual inputs

Knot DNS 2.5.4 (2017-08-31)
===========================

Improvements:
-------------
 - New minimum and maximum refresh interval config options (Thanks to Manabu Sonoda)
 - New warning when unforced flush with disabled zone file synchronization
 - New 'dnskey' keymgr command
 - Linking with libatomic on architectures that require it (Thanks to Pierre-Olivier Mercier)
 - Removed 'OK' from listing keymgr command outputs
 - Extended journal and keymgr documentation and logging

Bugfixes:
---------
 - Incorrect handling of specific corner-cases with zone-in-journal
 - The 'share' keymgr command doesn't work
 - Server crashes if configured with query-size and reply-size statistics options
 - Malformed big integer configuration values on some 32-bit platforms
 - Keymgr uses local time when parsing date inputs
 - Memory leak in kdig upon IXFR query

* Mon Jul 31 2017 Petr Spacek <petr.spacek@nic.cz> - 2.5.3-1
- new upstream release
WARNING: Automatic upgrade from versions 1.y.z is no longer possible.
To migrate, upgrade your packages gradually or use contacts listed on
https://www.knot-dns.cz/support/ (if you are in trouble).

* Mon Jul 31 2017 Petr Spacek <petr.spacek@nic.cz> - 2.5.3-2
- disable dnstap on RHEL (depedencies are missing)

* Mon Jul 31 2017 Petr Spacek <petr.spacek@nic.cz> - 2.5.3-1
- new upstream release
WARNING: Automatic upgrade from versions 1.y.z is no longer possible.
To migrate, upgrade your packages gradually or use contacts listed on
https://www.knot-dns.cz/support/ (if you are in trouble).

Knot DNS 2.5.3 (2017-07-14)
===========================

Features:
---------
 - CSK rollover support for Single-Type Signing Scheme

Improvements:
-------------
 - Allowed binding to non-local adresses for TCP (Thanks to Julian Brost!)
 - New documentation section for manual DNSSEC key algorithm rollover
 - Initial KSK also generated in the submission state
 - The 'ds' keymgr command with no parameter uses all KSK keys
 - New debug mode in kjournalprint
 - Updated keymgr documentation

Bugfixes:
---------
 - Sometimes missing RRSIG by KSK in submission state.
 - Minor DNSSEC-related issues

Knot DNS 2.5.2 (2017-06-23)
===========================

Security:
---------
 - CVE-2017-11104: Improper TSIG validity period check can allow TSIG forgery (Thanks to Synacktiv!)

Improvements:
-------------
 - Extended debug logging for TSIG errors
 - Better error message for unknown module section in the configuration
 - Module documentation compilation no longer depends on module configuration
 - Extended policy section configuration semantic checks
 - Improved python version compatibility in pykeymgr
 - Extended migration section in the documentation
 - Improved DNSSEC event timing on 32-bit systems
 - New KSK rollover start log info message
 - NULL qtype support in kdig

Bugfixes:
---------
 - Failed to process included configuration
 - dnskey_ttl policy option in the configuration has no effect on DNSKEY TTL
 - Corner case journal fixes (huge changesets, OpenWRT operation)
 - Confusing event timestamps in knotc zone-status output
 - NSEC/NSEC3 bitmap not updated for CDS/CDNSKEY
 - CDS/CDNSKEY RRSIG not updated

Knot DNS 2.5.1 (2017-06-07)
===========================

Bugfixes:
---------
 - pykeymgr no longer crash on empty json files in the KASP DB directory
 - pykeymgr no longer imports keys in the "removed" state
 - Imported keys in the "removed" state no longer makes knotd to crash
 - Including an empty configuration directory no longer makes knotd to crash
 - pykeymgr is distributed and installed to the distribution tarball

Knot DNS 2.5.0 (2017-06-05)
===========================

Features:
---------
 - KASP database switched from JSON files to LMDB database
 - KSK rollover support using CDNSKEY and CDS in the automatic DNSSEC signing
 - Dynamic module loading support with proper module API
 - Journal can store full zone contents (not only differences)
 - Zone freeze/thaw support
 - Updated knotc zone-status output with optional column filters
 - New '[no]crypto' option in kdig
 - New keymgr implementation reflecting KASP database changes
 - New pykeymgr for JSON-based KASP database migration
 - Removed obsolete knot1to2 utility

Improvements:
-------------
 - Added libidn2 support to kdig (with libidn fallback)
 - Maximum timer database switched from configure to the server configuration

Knot DNS 2.4.4 (2017-06-05)
===========================

Improvements:
-------------
 - Improved error handling in kjournalprint

Bugfixes:
---------
 - Zone flush not replanned upon unsuccessful flush
 - Journal inconsistency after deleting deleted zone
 - Zone events not rescheduled upon server reload (Thanks to Mark Warren)
 - Unreliable LMDB mapsize detection in kjournalprint
 - Some minor issues found by AddressSanitizer

Knot DNS 2.4.3 (2017-04-11)
===========================

Improvements:
-------------
 - New 'journal-db-mode' optimization configuration option
 - The default TSIG algorithm for utilities input is HMAC-SHA256
 - Implemented sensible default EDNS(0) padding policy (Thanks to D. K. Gillmor)
 - Added some more semantic checks on the knotc configuration operations

Bugfixes:
---------
 - Missing 'zone' keyword in the YAML output
 - Missing trailing dot in the keymgr DS owner output
 - Journal logs 'invalid parameter' in several cases
 - Some minor journal-related problems

Knot DNS 2.4.2 (2017-03-23)
===========================

Features:
---------
 - Zscanner can store record comments placed on the same line
 - Knotc status extension with version, configure, and workers parameters

Improvements:
-------------
 - Significant incoming XFR speed-up in the case of many zones

Bugfixes:
---------
 - Double OPT RR insertion when a global module returns KNOT_STATE_FAIL
 - User-driven zscanner parsing logic inconsistency
 - Lower serial at master doesn't trigger any errors
 - Queries with too long DNAME substitution do not return YXDOMAIN response
 - Incorrect elapsed time in the DDNS log
 - Failed to process forwarded DDNS request with TSIG

* Mon Mar 13 2017 Petr Spacek <petr.spacek@nic.cz> - 2.4.1-2
- configuration checking was fixed to be compatible with Knot 2.4.x

* Mon Feb 27 2017 Petr Spacek <petr.spacek@nic.cz> - 2.4.1-1
- new upstream release 2.4.1 replaces old 1.6.x series which is not supported
- configuration should be upgraded automatically using knot1to2 tool
- make sure you reviewed the new configuration in /etc/knot directory!

* Tue Aug 09 2016 Jan Vcelak <jvcelak@fedoraproject.org> - 1.6.8-1
- new upstream release:
  + feature: Zone size limit restriction for DDNS, AXFR, and IXFR (CVE-2016-6171)

* Wed Feb 10 2016 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.7-1
- new upstream release:
  + improvement: Log change of the zone serial number after IXFR transfer
  + improvement: Document operational impact of various RRL settings
  + improvement: Add support for rate-limit-slip zero
  + improvement: Add 'timer-db' configuration option

* Wed Nov 25 2015 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.6-1
- new upstream release:
  + security fix: out-of-bound read in packet parser for malformed NAPTR record
  + fix: systemd startup notifications

* Wed Sep 02 2015 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.5-1
- new upstream release:
  + fix: don't load expired zones on reload and startup
  + fix: remove race condition in scheduling causing delaying of events
  + fix: NSEC proof construction in zones with many delegations
  + fix: TC flag setting in RRL slipped answers
  + fix: disable domain name compression for root label
  + fix: check if executed under systemd before using journald log sink
  + feature: write persistent timers on server shutdown for better performance
  + feature: support time unit specification for 'max-conn-idle',
    'max-conn-handshake', 'max-conn-reply', and 'notify-timeout' config options
  + feature: add 'request-edns-config' config option

* Thu Jun 18 2015 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.4-1
- new upstream release:
  + fix: lost NOTIFY message if received during zone transfer
  + fix: kdig, record correct dnstap SocketProtocol when retrying over TCP
  + fix: kdig, hide TSIG section with +noall
  + fix: do not set AA flag for AXFR/IXFR queries
  + feature: zone scanner, split long TXT/SPF strings into multiple strings
  + feature: kdig, add +generic dump style option
  + feature: try all servers on failure in multi-master environment
  + improvement: zone dump, do not print class for SOA record for consistency

* Wed Apr 08 2015 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.3-1
- new upstream release:
  + fix: performance drop for NSEC-signed zones
  + fix: proper handling of TCP short-writes
  + fix: possible out-of-bound reads in zone parser and packet parser
  + feature: CDS and CDNSKEY support in zone parser
  + improvement: add defaults for TCP config options into documentation
  + improvement: detailed error message if zone reload fails

* Thu Feb 19 2015 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.2-1
- new upstream release:
  + new config option 'max-tcp-clients'
  + fix possible resource leak when terminating inactive TCP clients

* Tue Jan 20 2015 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.1-3
- service file changes:
  + remove dependency on network.target
  + remove bounding capabilities (breaks reload)

* Sat Dec 13 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.1-2
- new upstream release:
  + DNSSEC: support for Single-Type Signing Scheme
  + fix: journal file growing over configured limit
- service file changes:
  + run as 'knot' user and group
  + set security bounding capabilities
  + change Type to 'notify'

* Thu Oct 30 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.0-2
- default config: run server as unprivileged user
- service file: remove useless startup dependencies
- service file: add bounding capabilities

* Thu Oct 23 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.6.0-1
- new upstream release:
  + support for persistent zone timers (expire, refresh, and flush)
  + DNSSEC: RFC-compliant processing of letter case in RDATA domain names
  + EDNS: return minimal response for queries with unsupported version
  + EDNS: fix interpretation of Extended RCODE
  + transfers: fix forced zone retransfer
  + timers: properly expire zone when transfer is being refused by master

* Mon Sep 15 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.5.3-1
- new upstream release:
  + fix crash on specific incoming IXFR message
  + fix rare synchronization error during server reload
  + fix crash in reverse record synthesis module on DNSSEC signed zones
  + fix message ID and opcode for AXFR-style IXFR responses
  + fix sending of large responses to remote control commands

* Mon Sep 08 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.5.2-1
- new upstream release:
  + CVE-2014-0486: remote crash using crafted DNS message
  + transfers: do not refuse AXFR answers to IXFR queries
  + fix storing of hash character '#' in zone file

* Tue Aug 19 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.5.1-1
- new upstream release:
  + logging: unified logging messages
  + logging: support for systemd journal
  + DDNS: processing updates in bulk
  + DDNS: fix signing of responses with TSIG
  + DDNS: fix prerequisites checking in apex node
  + DNSSEC: fix domain names conversion to canonical format before signing
  + DNSSEC: semantic checks for signing keys
  + EDNS: fix inclusion of OPT record into some packets
  + knsupdate: fix use of zone origin for deletions

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 10 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.5.0-1
- update to 1.5.0
  + reimplemented DDNS forwarding
  + transfer sizes logged in bytes
  + logging of outgoing/incoming NOTIFY messages
  + zone flush planning after bootstrap
  + DDNS signing changes freeing
  + knotc key handling
- update to 1.5.0-rc2
  + edns-client-subnet support in kdig
  + optional asynchronous startup (config 'asynchronous-start')
  + preempt task queue for faster reload
  + lazy zone file write after zone transfer (config 'zonefile-sync')
  + close zone transfer after SERVFAIL response
  + incremental to full zone transfer fallback, wrong log message
  + zone events corner cases, reload replanning
- update to 1.5.0-rc1
  + Pluggable query processing modules
  + Synthetic IPv4/IPv6 reverse/forward records (optional module)
  + Dnstap support in both utilities & server (optional module)
  + NOTIFY message support and new TSIG section in kdig
  + Multi-master support
  + Query processing and core functionality overhaul
  + Performance and reduced memory footprint
  + Faster zone events scheduling
  + RFC compliant queries/responses in some corner cases
  + Log messages
  + New documentation (Sphinx)
- enabled dynamic linking
- removed info pages

* Wed Jun 18 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.7-1
- update to 1.4.7
  + Fixed DDNS corner cases
  + Fixed zone EXPIRE timer
  + Fixed semantic checks false positives
  + Fixed sending malformed IXFR with automatic DNSSEC
  + Fixed NAPTR record serialization

* Thu May 22 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.6-2
- update to 1.4.6
  + DNSSEC: fix possible signing loop when doing key rollover
  + RRL: fixed sending of malformed UDP empty responses

* Mon Apr 14 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.5-1
- update to 1.4.5
  + fix weakness in TSIG digest checking

* Thu Mar 27 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.4-1
- update to 1.4.4
  + server is logging remote control commands
  + 'knotc reload' doesn't refresh unchanged zones
  + 'knotc -f refresh' forces zone retransfer
  + missing notifications after DDNS/automatic resign
  + zone is rebootstrapped if the zone file is unreadable
  + progressive bootstrap retry backoff
  + zone file parser allows asterisk as part of the label
  + journal maximum entry size fixes
  + sign DNSKEYs in non-apex nodes as regular RR sets
  + various spelling and typo fixes

* Tue Feb 18 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.3-1
- update to 1.4.3
  + DNSSEC: fixes in authenticated denial proofs
  + zone parser: case insensitive comparison of $ORIGIN
  + journal: fix corruption if zone loading fails
  + config: add support for includes of directories

* Wed Feb 12 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.2-3
- rebuild with new userspace-rcu

* Mon Jan 27 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.2-2
- enable IDN support in domain names

* Mon Jan 27 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.2-1
- update to 1.4.2

* Mon Jan 13 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.1-1
- update to 1.4.1

* Mon Jan 06 2014 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.0-1
- update to 1.4.0

* Fri Dec 13 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.0-0.2.rc2
- update to 1.4.0-rc2

* Tue Nov 26 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.4.0-0.1.rc1
- update to 1.4.0-rc1

* Tue Oct 08 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.3.2-2
- fix failing wire reading/writing tests on big endian (#1015976)

* Tue Oct 01 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.3.2-1
- update to 1.3.2
  + possibility to set max UDP payload in EDNS0
  + fixed bug limiting payload size in some TCP responses
  + fixed closing of file descriptors for included files in config

* Sun Sep 01 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.3.1-1
- update to 1.3.1

* Mon Jul 29 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.3.0-0.4.rc5
- update to 1.3.0-rc5

* Mon Jul 15 2013 Paul Wouters <pwouters@redhat.com> - 1.3.0-0.3.rc4
- Added Alias=knotd.service alias to service file
- Added ExecStartPre=/usr/sbin/knotc checkconf to service file

* Mon Jul 15 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.3.0-0.2.rc4
- update to 1.3.0-rc4

* Wed Jul 03 2013 Jan Vcelak <jvcelak@fedoraproject.org> 1.3.0-0.1.rc3
- update to 1.3.0-rc3
- update configuration
- disable assertions in the code (define NDEBUG)
- enable unit tests as a part of RPM build process
- enable fast zone parser
- fix wrong dates in changelog

* Fri Apr 05 2013 Paul Wouters <pwouters@redhat.com> - 1.2.0-1
- Updated to 1.2.0-1
- Enabled hardening/relro/pie protection

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec 20 2012 Paul Wouters <pwouters@redhat.com> - 1.1.3-2
- Use new systemd macros

* Thu Dec 20 2012 Paul Wouters <pwouters@redhat.com> - 1.1.3-1
- Initial build for Fedora

* Thu Nov 22 2012 Ondřej Surý <ondrej@sury.org> - 1.1.2-1
- Update to 1.1.2

* Wed Nov 7 2012 Stanislav Petr <glux@glux.org> - 1.1.1-1
- Fixed build problem
- Update to 1.1.1
- Add man5 directory
- Add knot.info.gz to infodir

* Mon Aug 27 2012 Stanislav Petr <glux@glux.org> - 1.1.0-1
- Update to 1.1.0-rc2
- Fix default knot.conf
- Add build dependency to texinfo

* Tue May 15 2012 Stanislav Petr <glux@glux.org> - 1.0.6-2
- Try to fix compilation problem on some systems - force add -lgcc_eh to gcc flags

* Sun May 13 2012 Stanislav Petr <glux@glux.org> - 1.0.6-1
- Update to versio 1.0.6
- Change attrs to 750 on /etc/knot - only for root (knot configuration can contain DNS keys for zone updates)
- Clean content in /etc/knot

* Tue May 1 2012 Stanislav Petr <glux@glux.org> - 1.0.5-1
- Update to version 1.0.5

* Wed Apr 18 2012 Stanislav Petr <glux@glux.org> - 1.0.3-1
- Fixed knot directory ownership.
- Update to version 1.0.3
- Merget changes from Paul Wouters <pwouters@redhat.com> 
- Removed unnecessary commands pro %%post script
- Add knot user
- More configuration samples in /usr/share/doc/knot

* Thu Mar 1 2012 Stanislav Petr <glux@glux.org> - 1.0.0-4
- Update to upstream version 1.0.0
- Fix %%{_sharedstatedir} usage in .spec.
- Fix file and directories ownership
- Fix service upgrade in postun in rpm.
- Do not install unittests.

* Wed Jan 25 2012 Stanislav Petr <glux@glux.org> - 0.9.1-3
- Update to upstream version 0.9.1

* Mon Dec 12 2011 Stanislav Petr <glux@glux.org> - 0.8.1-3
- Add docs (COPYING AUTHORS RELNOTES KNOWN_ISSUES)
- Update rpm building options.
  Use %%{_sharedstatedir} instead of %%{_var}/lib,
  dafault value for %%{buildroot} path
- Remove ldconfig from post and postun in rpm.
- Update licence to GPLv3+

* Wed Dec 07 2011 Stanislav Petr <glux@glux.org> - 0.8.1-2
- RPM build fix

* Mon Dec 05 2011 Stanislav Petr <glux@glux.org> - 0.8.1-1
- Create
